<?php

namespace App\Http\Controllers\Admin;

use App\Constants\Status;
use App\Http\Controllers\Controller;
use App\Models\Plan;
use App\Models\Ptc;
use App\Models\Referral;
use Illuminate\Http\Request;

class PlanController extends Controller
{
    public function index()
    {
        $pageTitle = 'Subscription Plan';
        $levels = Referral::max('level');
        $plans = Plan::get();
        return view('admin.plan',compact('pageTitle','levels','plans'));
    }

    public function details(Request $request)
    {
        $plan = Plan::find($request->plan_id);
        return response()->json(['plan'=>$plan]);
    }



    public function savePlan(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'tagline' => 'required',
            'price' => 'required|numeric|min:0',
            'ptc_rate' => 'required|numeric|min:0',
            'daily_limit' => 'required|numeric|min:1',
            // 'ref_level' => 'required|numeric|min:0',
            'validity' => 'required|numeric|min:0',
            'min_withdraw' => 'required|numeric|min:0',
            'max_withdraw' => 'required|numeric|gt:min_withdraw',
        ]);

        if($request->id == 0){
            $plan = new Plan();
        }else{
            $plan = Plan::findOrFail($request->id);

            // update ads rate
            $ads = Ptc::where('plan_id', $plan->id)->get();
            foreach ($ads as $key => $ad) {
                $ad->amount = $request->ptc_rate;
                $ad->save();
            }
        }
        $plan->name = $request->name;
        $plan->tagline = $request->tagline;
        $plan->price = $request->price;
        $plan->ptc_rate = $request->ptc_rate;
        $plan->daily_limit = $request->daily_limit;
        // $plan->ref_level = $request->ref_level;
        $plan->validity = $request->validity;
        $plan->min_withdraw = $request->min_withdraw;
        $plan->max_withdraw = $request->max_withdraw;
        $plan->highlight = isset($request->highlight) ? Status::YES : Status::NO;
        $plan->save();



        $notify[] = ['success', 'Plan has been Updated Successfully.'];
        return back()->withNotify($notify);
    }

    public function status(Request $request){

        return Plan::changeStatus($request->id);
    }

}
