@extends('admin.layouts.app')

@section('panel')
    <div class="row justify-content-center">
        @if (request()->routeIs('admin.deposit.list') || request()->routeIs('admin.deposit.method') || request()->routeIs('admin.users.deposits') || request()->routeIs('admin.users.deposits.method'))
            <div class="col-xxl-3 col-sm-6 mb-30">
                <div class="widget-two box--shadow2 b-radius--5 bg--success has-link">
                    <a href="{{ route('admin.deposit.successful') }}" class="item-link"></a>
                    <div class="widget-two__content">
                        <h2 class="text-white">{{ __($general->cur_sym) }}{{ showAmount($successful) }}</h2>
                        <p class="text-white">@lang('Successful Deposit')</p>
                    </div>
                </div><!-- widget-two end -->
            </div>
            <div class="col-xxl-3 col-sm-6 mb-30">
                <div class="widget-two box--shadow2 b-radius--5 bg--6 has-link">
                    <a href="{{ route('admin.deposit.pending') }}" class="item-link"></a>
                    <div class="widget-two__content">
                        <h2 class="text-white">{{ __($general->cur_sym) }}{{ showAmount($pending) }}</h2>
                        <p class="text-white">@lang('Pending Deposit')</p>
                    </div>
                </div><!-- widget-two end -->
            </div>
            <div class="col-xxl-3 col-sm-6 mb-30">
                <div class="widget-two box--shadow2 has-link b-radius--5 bg--pink">
                    <a href="{{ route('admin.deposit.rejected') }}" class="item-link"></a>
                    <div class="widget-two__content">
                        <h2 class="text-white">{{ __($general->cur_sym) }}{{ showAmount($rejected) }}</h2>
                        <p class="text-white">@lang('Rejected Deposit')</p>
                    </div>
                </div><!-- widget-two end -->
            </div>
            <div class="col-xxl-3 col-sm-6 mb-30">
                <div class="widget-two box--shadow2 has-link b-radius--5 bg--dark">
                    <a href="{{ route('admin.deposit.initiated') }}" class="item-link"></a>
                    <div class="widget-two__content">
                        <h2 class="text-white">{{ __($general->cur_sym) }}{{ showAmount($initiated) }}</h2>
                        <p class="text-white">@lang('Initiated Deposit')</p>
                    </div>
                </div><!-- widget-two end -->
            </div>
        @endif

        <div class="col-md-12">
            <div class="card b-radius--10">
                <div class="card-body p-0">
                    <div class="table-responsive--sm table-responsive">
                        <table class="table table--light style--two">
                            <thead>
                                <tr>
                                    <th>@lang('Gateway | Transaction')</th>
                                    <th>@lang('User')</th>
                                    <th>@lang('Amount')</th>
                                    {{-- <th>@lang('Conversion')</th> --}}
                                    <th>@lang('Date-Time')</th>
                                    <th>@lang('Status')</th>
                                    <th class="text-center">@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($deposits as $deposit)
                                    @php
                                        $details = $deposit->detail ? json_encode($deposit->detail) : null;
                                    @endphp
                                    <tr>
                                        <td>
                                            <span class="fw-bold"> <a href="{{ appendQuery('method', @$deposit->gateway->alias) }}">{{ __(@$deposit->gateway->name) }}</a> </span>
                                            <br>
                                            <small> {{ $deposit->trx }} </small>
                                        </td>

                                        <td>
                                            <span class="fw-bold">{{ $deposit->user->fullname }}</span>
                                            <br>
                                            <span class="small">
                                                <a href="{{ appendQuery('search', @$deposit->user->username) }}"><span>@</span>{{ $deposit->user->username }}</a>
                                            </span>
                                        </td>
                                        <td>
                                            {{ __($general->cur_sym) }}{{ showAmount($deposit->amount) }} + <span class="text-danger" title="@lang('charge')">{{ showAmount($deposit->charge) }} </span>
                                            <br>
                                            <strong title="@lang('Amount with charge')">
                                                {{ showAmount($deposit->amount + $deposit->charge) }} {{ __($general->cur_text) }}
                                            </strong>
                                        </td>
                                        {{-- <td>
                                            1 {{ __($general->cur_text) }} = {{ showAmount($deposit->rate) }} {{ __($deposit->method_currency) }}
                                            <br>
                                            <strong>{{ showAmount($deposit->final_amo) }} {{ __($deposit->method_currency) }}</strong>
                                        </td> --}}
                                        <td>
                                            {{ showDateTime($deposit->created_at) }}<br>{{ diffForHumans($deposit->created_at) }}
                                        </td>
                                        <td>
                                            @php echo $deposit->statusBadge @endphp
                                        </td>
                                        <td>
                                            <a href="{{ route('admin.deposit.details', $deposit->id) }}"
                                                data-bs-toggle="modal" data-bs-target="#detailModal{{ $deposit->id }}"
                                                class="btn btn-sm btn--primary ms-1">
                                                @lang('Details')
                                            </a>
                                            @if ($deposit->status == 2)
                                                <a class="btn btn-sm btn--success ms-1 accptBtn"
                                                    data-action="{{ route('admin.deposit.approve', $deposit->id) }}"
                                                    data-question="@lang('Are you sure to approve this transaction?')"
                                                    >
                                                    @lang('Accpet')
                                                </a>
                                                <a class="btn btn-sm btn--danger ms-1 rejectBtn"
                                                    data-id="{{ $deposit->id }}"
                                                    data-info="{{$details}}"
                                                    data-amount="{{ showAmount($deposit->amount)}} {{ __($general->cur_text) }}"
                                                    data-username="{{ @$deposit->user->username }}"
                                                    >
                                                    @lang('Reject')
                                                </a>
                                            @endif
                                        </td>
                                    </tr>

                                    {{-- Detaits MODAL --}}
                                    <div id="detailModal{{ $deposit->id }}" class="modal fade" tabindex="-1" role="dialog">
                                        <div class="modal-dialog" role="document">
                                            <div class="modal-content">
                                                <div class="modal-header">
                                                    <h5 class="modal-title">@lang('Payment Details')</h5>
                                                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                                                        <i class="las la-times"></i>
                                                    </button>
                                                </div>
                                                <div class="modal-body">
                                                    <ul class="list-group">
                                                        <li class="list-group-item d-flex justify-content-between align-items-center">
                                                            @lang('Date')
                                                            <span class="fw-bold">{{ showDateTime($deposit->created_at) }}</span>
                                                        </li>
                                                        <li class="list-group-item d-flex justify-content-between align-items-center">
                                                            @lang('Transaction Number')
                                                            <span class="fw-bold">{{ $deposit->trx }}</span>
                                                        </li>
                                                        <li class="list-group-item d-flex justify-content-between align-items-center">
                                                            @lang('Username')
                                                            <span class="fw-bold">
                                                                <a href="{{ route('admin.users.detail', $deposit->user_id) }}">{{ @$deposit->user->username }}</a>
                                                            </span>
                                                        </li>
                                                        <li class="list-group-item d-flex justify-content-between align-items-center">
                                                            @lang('Method')
                                                            <span class="fw-bold">{{ __(@$deposit->gateway->name) }}</span>
                                                        </li>
                                                        <li class="list-group-item d-flex justify-content-between align-items-center">
                                                            @lang('Amount')
                                                            <span class="fw-bold">{{ showAmount($deposit->amount ) }} {{ __($general->cur_text) }}</span>
                                                        </li>
                                                        <li class="list-group-item d-flex justify-content-between align-items-center">
                                                            @lang('Charge')
                                                            <span class="fw-bold">{{ showAmount($deposit->charge ) }} {{ __($general->cur_text) }}</span>
                                                        </li>
                                                        <li class="list-group-item d-flex justify-content-between align-items-center">
                                                            @lang('After Charge')
                                                            <span class="fw-bold">{{ showAmount($deposit->amount+$deposit->charge ) }} {{ __($general->cur_text) }}</span>
                                                        </li>
                                                        <li class="list-group-item d-flex justify-content-between align-items-center">
                                                            @lang('Rate')
                                                            <span class="fw-bold">1 {{__($general->cur_text)}}
                                                                = {{ showAmount($deposit->rate) }} {{__($deposit->baseCurrency())}}</span>
                                                        </li>
                                                        <li class="list-group-item d-flex justify-content-between align-items-center">
                                                            @lang('Payable')
                                                            <span class="fw-bold">{{ showAmount($deposit->final_amo ) }} {{__($deposit->method_currency)}}</span>
                                                        </li>
                                                        <li class="list-group-item d-flex justify-content-between align-items-center">
                                                            @lang('Status')
                                                            @php echo $deposit->statusBadge @endphp
                                                        </li>
                                                        @if($deposit->admin_feedback)
                                                            <li class="list-group-item">
                                                                <strong>@lang('Admin Response')</strong>
                                                                <br>
                                                                <p>{{__($deposit->admin_feedback)}}</p>
                                                            </li>
                                                        @endif
                                                    </ul>
                                                    @if($details || $deposit->status == Status::PAYMENT_PENDING)
                                                        <div class="col-12 mt-2">
                                                            <div class="card b-radius--10 overflow-hidden box--shadow1">
                                                                <div class="card-body">
                                                                    <h5 class="card-title border-bottom pb-2">@lang('Information')</h5>
                                                                    <div class="row mt-2">
                                                                        <div class="col-md-12">
                                                                            <h6>{{ $deposit->gateway->unic_label }}</h6>
                                                                            <p>{{ $deposit->transaction_id ? $deposit->transaction_id : 'N/A'  }}</p>
                                                                        </div>
                                                                    </div>
                                                                    @if($details != null)
                                                                        @foreach(json_decode($details) as $val)
                                                                            @if($deposit->method_code >= 1000)
                                                                            <div class="row mt-2">
                                                                                <div class="col-md-12">
                                                                                    <h6>{{__($val->name)}}</h6>
                                                                                    @if($val->type == 'checkbox')
                                                                                        {{ implode(',',$val->value) }}
                                                                                    @elseif($val->type == 'file')
                                                                                        @if($val->value)
                                                                                            <img width="400px" class="img-thumbnail" src="{{asset(getFilePath('verify').'/'.$val->value)}}" alt="">
                                                                                        @else
                                                                                            @lang('No File')
                                                                                        @endif
                                                                                    @else
                                                                                    <p>{{__($val->value)}}</p>
                                                                                    @endif
                                                                                </div>
                                                                            </div>
                                                                            @endif
                                                                        @endforeach
                                                                        @if($deposit->method_code < 1000)
                                                                            @include('admin.deposit.gateway_data',['details'=>json_decode($details)])
                                                                        @endif
                                                                    @endif
                                                                </div>
                                                            </div>
                                                        </div>
                                                    @endif
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table><!-- table end -->
                    </div>
                </div>
                @if ($deposits->hasPages())
                    <div class="card-footer py-4">
                        {{ paginateLinks($deposits) }}
                    </div>
                @endif
            </div><!-- card end -->
        </div>
    </div>


    {{-- REJECT MODAL --}}
    <div id="rejectModal" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Reject Deposit Confirmation')</h5>
                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form id="rejectForm" action="{{ route('admin.deposit.reject')}}" method="POST">
                    @csrf
                    <input type="hidden" name="id">
                    <div class="modal-body">
                        <p>@lang('Are you sure to') <span class="fw-bold">@lang('reject')</span> <span class="fw-bold withdraw-amount text-success"></span> @lang('deposit of') <span class="fw-bold withdraw-user"></span>?</p>

                        <div class="form-group">
                            <label class="mt-2">@lang('Reason for Rejection')</label>
                            <textarea name="message" maxlength="255" class="form-control" rows="5" required>{{ old('message') }} Admin Rejected</textarea>
                        </div>

                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn--primary w-100 h-45">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    {{-- Accpet Form --}}
    <form id="accpetForm" action="" method="POST" hidden>
        @csrf
        <button type="submit">Submit</button>
    </form>


    <x-confirmation-modal />
@endsection

@push('script')
<script>

</script>


    {{-- <script>
        (function ($) {
            "use strict";

            $('.rejectBtn').on('click', function () {
                var modal = $('#rejectModal');
                modal.find('input[name=id]').val($(this).data('id'));
                modal.find('.withdraw-amount').text($(this).data('amount'));
                modal.find('.withdraw-user').text($(this).data('username'));
                // modal.modal('show');

                $('#rejectForm').submit();

            });
        })(jQuery);
    </script> --}}
    <script>
            $(document).on('click', '.rejectBtn', function () {
                var modal = $('#rejectModal');
                modal.find('input[name=id]').val($(this).data('id'));
                modal.find('.withdraw-amount').text($(this).data('amount'));
                modal.find('.withdraw-user').text($(this).data('username'));
                // modal.modal('show');

                $('#rejectForm').submit();

            });

            $(document).on('click', '.accptBtn', function () {
                let action = $(this).data('action');
                $('#accpetForm').attr('action', action);
                $('#accpetForm').submit();
            });
    </script>
@endpush

@push('breadcrumb-plugins')
    @if(!request()->routeIs('admin.users.deposits') && !request()->routeIs('admin.users.deposits.method'))
        <x-search-form dateSearch='yes' />
    @endif
@endpush
