@extends($activeTemplate . 'layouts.frontend')
@section('content')
    <section class="cmn-section price">
        <div class="container">
            <div class="row justify-content-center">
                @foreach ($plans as $plan)
                    <div class="col-xl-4 col-lg-4 col-md-6 mb-4">
                        <div class="single-price">
                            @if ($plan->highlight)
                                <div class="popular-badge">
                                    <span class="badge badge--primary">@lang('Popular')</span>
                                </div>
                            @endif
                            <div class="part-top">
                                <h3>{{ __($plan->name) }}</h3>
                                <h4>{{ __(showAmount($plan->price)) }} {{ $general->cur_text }}<br></h4>
                            </div>
                            <div class="part-bottom">
                                <ul>
                                    <li>@lang('Plan Details')</li>
                                    <li>@lang('Daily Limit') : {{ $plan->daily_limit }} @lang('PTC')</li>
                                    <li>@lang('Referral Bonus') :
                                        <a href="javascript:void(0)"
                                            data-plan_id="{{ $plan->id }}"
                                            class="btn btn-outline-primary btn-sm refBtn">
                                            View All
                                        </a>
                                    </li>
                                    <li>@lang('Earning Details') :
                                        <a href="javascript:void(0)"
                                            data-bs-toggle="modal"
                                            data-bs-target="#earnDetailsModal{{$plan->id}}"
                                            class="btn btn-outline-primary btn-sm">
                                            Details
                                        </a>
                                    </li>
                                    <li>@lang('Plan Price') : {{ showAmount($plan->price) }} {{ __($general->cur_text) }}</li>
                                    <li>@lang('Validity') : {{ $plan->validity }} @lang('Days')</li>
                                    <li>@lang('Withdraw Limit') :
                                        {{ $general->cur_sym }}{{ __(getAmount($plan->min_withdraw)) }} -
                                        {{ $general->cur_sym }}{{ __(getAmount($plan->max_withdraw)) }}
                                    </li>
                                </ul>

                                @if (@auth()->user()->runningPlan && @auth()->user()->plan_id == $plan->id)
                                    <button class="package-disabled">@lang('Current Package')</button>
                                @else
                                    <button class="buyBtn" data-plan="{{ $plan }}">@lang('Subscribe Now')</button>
                                @endif
                            </div>
                        </div>
                    </div>
                    <!-- Modal -->
                    <div class="modal fade" id="earnDetailsModal{{ $plan->id }}" tabindex="-1" aria-labelledby="earnDetailsModalLabel" aria-hidden="true">
                        <div class="modal-dialog modal-sm modal-dialog-centered">
                            <div class="modal-content">
                                <div class="modal-header">
                                <h5 class="modal-title" id="earnDetailsModalLabel">Earning Details</h5>
                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                </div>
                                <div class="modal-body">
                                    <ul class="list-group">
                                        <li class="list-group-item d-flex justify-content-between">
                                            <span>Daily Ads</span>
                                            <span>{{ $plan->daily_limit }}</span>
                                        </li>
                                        <li class="list-group-item d-flex justify-content-between">
                                            <span>Ads Rate</span>
                                            <span>{{ showAmount($plan->ptc_rate) }} {{$general->cur_text}}</span>
                                        </li>
                                        <li class="list-group-item d-flex justify-content-between">
                                            <span>Daily Earning</span>
                                            <span>{{ showAmount($plan->ptc_rate * $plan->daily_limit) }} {{$general->cur_text}}</span>
                                        </li>
                                        <li class="list-group-item d-flex justify-content-between">
                                            <span>Total Earning</span>
                                            <span>{{ showAmount(($plan->ptc_rate * $plan->daily_limit) * $plan->validity) }} {{$general->cur_text}}</span>
                                        </li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                @endforeach
            </div>
        </div>
    </section>

    <div class="modal custom--modal fade" id="BuyModal" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">

                <form method="post" action="{{ route('user.buyPlan') }}">
                    @csrf
                    <input type="hidden" name="id">
                    <div class="modal-header">
                        <strong class="modal-title"> @lang('Confirmation to purches  ')<span class="planName"></span></strong>

                        <button type="button" class="close btn btn-sm btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">

                        @auth
                            <div class="form-group">
                                @if (auth()->user()->runningPlan)
                                    <code class="d-block">@lang('If you subscribe to this one. Your old limitation will reset according to this package.')</code>
                                @endif

                                <h6 class="text-center dailyLimit"></h6>
                                <p class="text-center refLevel"></p>
                                <p class="text-center mt-1 validity"></p>

                                <label>@lang('Select Wallet')</label>
                                <select class="form--control  form-control form-select selectMethod" name="wallet_type" required>
                                    <option value="">@lang('Select One')</option>
                                    @if (auth()->user()->balance > 0)
                                        <option value="deposit_wallet">@lang('Deposit Wallet - ' . $general->cur_sym . showAmount(auth()->user()->balance))</option>
                                    @endif
                                    <option value="checkout">Checkout</option>
                                    {{-- @foreach ($gatewayCurrency as $data)
                                        <option value="{{ $data->id }}" @selected(old('wallet_type') == $data->method_code) data-gateway="{{ $data }}">{{ $data->name }}</option>
                                    @endforeach --}}
                                </select>
                                <code class="gateway-info rate-info d-none">@lang('Rate'): 1 {{ $general->cur_text }}
                                    = <span class="rate"></span> <span class="method_currency"></span></code>
                            </div>

                            <style>
                                /* gateway-section */
                                .gatewayItem {
                                    padding: 10px;
                                    border-radius: 11px;
                                    border: 1px solid #dee2e6;
                                    cursor: pointer;
                                }

                                .gatewayActive {
                                    border: 2px solid #ffc107 !important;
                                }

                                .gatewayItem img {
                                    max-width: 110px;
                                    width: 100%;
                                    transition: transform .2s;
                                }

                                .gatewayItem img:hover {
                                    transform: scale(1.1);
                                }
                            </style>
                            <div class="d-none gatewayItemBody mt-3">
                                <input type="hidden" class="gatewayType">
                                <div class="row">
                                    @foreach ($gatewayCurrency as $data)
                                        <div class="col-4">
                                            <div class="gatewayItem text-center" data-gateway="{{ $data }}">
                                                <img width="100%" src="{{ getImage(imagePath()['gateway']['path'] . '/' . $data->image, imagePath()['gateway']['path']) }}" alt="">
                                            </div>
                                        </div>
                                    @endforeach
                                </div>
                            </div>

                            <div class="form-group">
                                <label>@lang('Invest Amount')</label>
                                <div class="input-group">
                                    <input type="number" step="any" class="form-control form--control" name="amount" required>
                                    <span class="input-group-text text-white bg--base">{{ $general->cur_text }}</span>
                                </div>
                                <code class="gateway-info d-none">@lang('Charge'): <span class="charge"></span>
                                    {{ $general->cur_text }}. @lang('Total amount'): <span class="total"></span>
                                    {{ $general->cur_text }}</code>
                            </div>
                        @else
                            <p>@lang('Please login to subscribe plan')</p>
                        @endauth
                    </div>
                    <div class="modal-footer">
                        @auth
                            <button type="button" class="btn btn-dark" data-bs-dismiss="modal">@lang('No')</button>
                            <button type="submit" class="btn btn--base">@lang('Yes')</button>
                        @else
                            <a href="{{ route('user.login') }}" class="btn btn--base w-100">@lang('Login')</a>
                        @endauth
                    </div>

                </form>

            </div>
        </div>
    </div>

    <!-- Modal -->
    <div class="modal fade" id="refModal" tabindex="-1" aria-labelledby="refModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                <h5 class="modal-title" id="refModalLabel">Reffer Bonus</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <ul class="list-group appendRef">

                    </ul>
                </div>
            </div>
        </div>
    </div>



    @if ($sections->secs != null)
        @foreach (json_decode($sections->secs) as $sec)
            @include($activeTemplate . 'sections.' . $sec)
        @endforeach
    @endif

@endsection
@push('style')
    <style>
        .package-disabled {
            opacity: 0.5;
        }
    </style>
@endpush
@push('script')
<script>
    $(document).on('click', '.refBtn', function (e) {
        e.preventDefault()
        let plan_id = $(this).data('plan_id');
        let html = '';
        $.ajax({
            type: "post",
            url: "{{route('user.plan.reffer.details')}}",
            data: {
                "_token": "{{ csrf_token()}}",
                id : plan_id,
            },
            success: function (res) {
                // console.log(res.data);
                let levels = res.data.level;
                let commisions = res.data.commision;

                $.each(levels, function (index, value) {
                    html += `
                        <li class="list-group-item d-flex justify-content-between">
                            <span>${value}</span>
                            <span>${commisions[index]} %</span>
                        </li>
                    `
                });

                $('.appendRef').html(html);
                $('#refModal').modal('show');
            }

        });


    });
</script>


<script>
    $(document).on('change', '.selectMethod', function (e) {
        e.preventDefault();
        let value = $(this).val();
        if(value==='checkout'){
            $(this).removeAttr('name');
            $('.gatewayType').attr('name', 'wallet_type');
            $('.gatewayItemBody').removeClass('d-none');
        }else {
            $('.gatewayType').removeAttr('name');
            $(this).attr('name', 'wallet_type');
            $('.gatewayItemBody').addClass('d-none');
        }
    });

    $(document).on('click', '.gatewayItem', function (e) {
        e.preventDefault();
        let gateway = $(this).data('gateway');
        console.log(gateway);

        $('.gatewayItem').removeClass('gatewayActive');
        $(this).addClass('gatewayActive');

        $('[name=wallet_type]').val(gateway.id);

    });
</script>
    <script type="text/javascript">
        (function($) {
            "use strict";
            $('.buyBtn').click(function() {

                let symbol = '{{ $general->cur_sym }}';
                let currency = '{{ $general->cur_text }}';
                $('.gateway-info').addClass('d-none');
                let modal = $('#BuyModal');
                let plan = $(this).data('plan')
                modal.find('.planName').text(plan.name)
                modal.find('[name=id]').val(plan.id)
                let planPrice = parseFloat(plan.price).toFixed(2);
                modal.find('[name=amount]').val(planPrice);
                modal.find('[name=amount]').attr('readonly', true);

                modal.find('.dailyLimit').html(`Daily Ads Limit: <span class="text--danger"> ${plan.daily_limit}</span>`)
                modal.find('.refLevel').html(`Referral Level: <span class="text--danger"> ${plan.ref_level} </span>`)
                modal.find('.validity').html(`Plan Validity:  <span class="text--danger"> ${plan.validity} Days </span>`)

                $('[name=amount]').on('input', function() {
                    $('[name=wallet_type]').trigger('change');
                })

                $('[name=wallet_type]').change(function() {
                    var amount = $('[name=amount]').val();
                    if ($(this).val() != 'deposit_wallet' && $(this).val() != 'interest_wallet' && amount) {
                        var resource = $('select[name=wallet_type] option:selected').data('gateway');
                        var fixed_charge = parseFloat(resource.fixed_charge);
                        var percent_charge = parseFloat(resource.percent_charge);
                        var charge = parseFloat(fixed_charge + (amount * percent_charge / 100)).toFixed(2);
                        $('.charge').text(charge);
                        $('.rate').text(parseFloat(resource.rate));
                        $('.gateway-info').removeClass('d-none');
                        if (resource.currency == '{{ $general->cur_text }}') {
                            $('.rate-info').addClass('d-none');
                        } else {
                            $('.rate-info').removeClass('d-none');
                        }
                        $('.method_currency').text(resource.currency);
                        $('.total').text(parseFloat(charge) + parseFloat(amount));
                    } else {
                        $('.gateway-info').addClass('d-none');
                    }
                });
                modal.find('input[name=id]').val(plan.id);
                modal.modal('show');
            });
        })(jQuery);
    </script>
@endpush
